==> jc-1.4.0.tar.gz: javax/xml/transform/TransformerConfigurationException.h <==
// public class javax.xml.transform.TransformerConfigurationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 58a4e08392958957 javax_xml_transform_TransformerConfigurationException
// @dep_class 97aa6a3c8a0119b8 javax_xml_transform_TransformerException

// header file dependencies
// @dep_header javax_xml_transform_TransformerException

#include "javax/xml/transform/TransformerException.h"

#ifndef _JC_javax_xml_transform_TransformerConfigurationException_H_
#define _JC_javax_xml_transform_TransformerConfigurationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_javax_xml_transform_SourceLocator$object;

// Typedefs
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$sub_refs	_jc_javax_xml_transform_TransformerConfigurationException$sub_refs;
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$sub_nonrefs	_jc_javax_xml_transform_TransformerConfigurationException$sub_nonrefs;
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$refs	_jc_javax_xml_transform_TransformerConfigurationException$refs;
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$nonrefs	_jc_javax_xml_transform_TransformerConfigurationException$nonrefs;
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$object	_jc_javax_xml_transform_TransformerConfigurationException$object;

typedef const struct _jc_javax_xml_transform_TransformerConfigurationException$vmethods	_jc_javax_xml_transform_TransformerConfigurationException$vmethods;
typedef const struct _jc_javax_xml_transform_TransformerConfigurationException$vtable	_jc_javax_xml_transform_TransformerConfigurationException$vtable;
typedef const struct _jc_javax_xml_transform_TransformerConfigurationException$vtype	_jc_javax_xml_transform_TransformerConfigurationException$vtype;

// Constructors
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *);
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$06eb59bac800a87f(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$b0c14bdcbed21966(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_javax_xml_transform_TransformerConfigurationException$vmethods {
};

// Vtable
struct _jc_javax_xml_transform_TransformerConfigurationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_transform_TransformerException$vmethods	javax_xml_transform_TransformerException;
	_jc_javax_xml_transform_TransformerConfigurationException$vmethods	javax_xml_transform_TransformerConfigurationException;
};

// Vtype
struct _jc_javax_xml_transform_TransformerConfigurationException$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_TransformerConfigurationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_TransformerConfigurationException$sub_refs {
	struct _jc_object	*locator;
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_TransformerConfigurationException$refs {
    _jc_javax_xml_transform_TransformerConfigurationException$sub_refs	javax_xml_transform_TransformerConfigurationException;
    _jc_javax_xml_transform_TransformerException$sub_refs	javax_xml_transform_TransformerException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_TransformerConfigurationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_TransformerConfigurationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_transform_TransformerException$sub_nonrefs	javax_xml_transform_TransformerException;
    _jc_javax_xml_transform_TransformerConfigurationException$sub_nonrefs	javax_xml_transform_TransformerConfigurationException;
};

// Object instance structure
struct _jc_javax_xml_transform_TransformerConfigurationException$object {
	_jc_javax_xml_transform_TransformerConfigurationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_TransformerConfigurationException$vtype	*vtype;
	_jc_javax_xml_transform_TransformerConfigurationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_TransformerConfigurationException$vtype _jc_javax_xml_transform_TransformerConfigurationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_TransformerConfigurationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_TransformerConfigurationException$class_object;

#endif	/* _JC_javax_xml_transform_TransformerConfigurationException_H_ */

==> jc-1.4.6.tar.gz: javax/xml/transform/TransformerConfigurationException.h <==
// public class javax.xml.transform.TransformerConfigurationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 58a4e08392958957 javax_xml_transform_TransformerConfigurationException
// @dep_class 97aa6a3c8a0119b8 javax_xml_transform_TransformerException

// header file dependencies
// @dep_header javax_xml_transform_TransformerException

#include "javax/xml/transform/TransformerException.h"

#ifndef _JC_javax_xml_transform_TransformerConfigurationException_H_
#define _JC_javax_xml_transform_TransformerConfigurationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_javax_xml_transform_SourceLocator$object;

// Typedefs
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$sub_refs	_jc_javax_xml_transform_TransformerConfigurationException$sub_refs;
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$sub_nonrefs	_jc_javax_xml_transform_TransformerConfigurationException$sub_nonrefs;
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$refs	_jc_javax_xml_transform_TransformerConfigurationException$refs;
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$nonrefs	_jc_javax_xml_transform_TransformerConfigurationException$nonrefs;
typedef struct _jc_javax_xml_transform_TransformerConfigurationException$object	_jc_javax_xml_transform_TransformerConfigurationException$object;

typedef const struct _jc_javax_xml_transform_TransformerConfigurationException$vmethods	_jc_javax_xml_transform_TransformerConfigurationException$vmethods;
typedef const struct _jc_javax_xml_transform_TransformerConfigurationException$vtable	_jc_javax_xml_transform_TransformerConfigurationException$vtable;
typedef const struct _jc_javax_xml_transform_TransformerConfigurationException$vtype	_jc_javax_xml_transform_TransformerConfigurationException$vtype;

// Constructors
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$06eb59bac800a87f(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$b0c14bdcbed21966(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_TransformerConfigurationException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_transform_TransformerConfigurationException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_transform_TransformerConfigurationException$vmethods {
};

// Vtable
struct _jc_javax_xml_transform_TransformerConfigurationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_transform_TransformerException$vmethods	javax_xml_transform_TransformerException;
	_jc_javax_xml_transform_TransformerConfigurationException$vmethods	javax_xml_transform_TransformerConfigurationException;
};

// Vtype
struct _jc_javax_xml_transform_TransformerConfigurationException$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_TransformerConfigurationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_TransformerConfigurationException$sub_refs {
	struct _jc_object	*locator;
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_TransformerConfigurationException$refs {
    _jc_javax_xml_transform_TransformerConfigurationException$sub_refs	javax_xml_transform_TransformerConfigurationException;
    _jc_javax_xml_transform_TransformerException$sub_refs	javax_xml_transform_TransformerException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_TransformerConfigurationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_TransformerConfigurationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_transform_TransformerException$sub_nonrefs	javax_xml_transform_TransformerException;
    _jc_javax_xml_transform_TransformerConfigurationException$sub_nonrefs	javax_xml_transform_TransformerConfigurationException;
};

// Object instance structure
struct _jc_javax_xml_transform_TransformerConfigurationException$object {
	_jc_javax_xml_transform_TransformerConfigurationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_TransformerConfigurationException$vtype	*vtype;
	_jc_javax_xml_transform_TransformerConfigurationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_TransformerConfigurationException$vtype _jc_javax_xml_transform_TransformerConfigurationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_TransformerConfigurationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_TransformerConfigurationException$class_object;

#endif	/* _JC_javax_xml_transform_TransformerConfigurationException_H_ */
